@@ -47,17 +47,17 @@ screenreg <- function(l, file = NULL, single.row = FALSE,
   # create output table with significance stars etc.
   ci <- logical()
   for (i in 1:length(models)) {
-    if (length(models[[i]]@se) == 0) {
+    if (length(models[[i]]@se) == 0 && length(models[[i]]@ci.up) > 0) {
       ci[i] <- TRUE
     } else {
       ci[i] <- FALSE
     }
   }
   output.matrix <- outputmatrix(m, single.row, neginfstring = "-Inf", 
-      leading.zero, digits, se.prefix = " (", se.suffix = ")", 
-      star.prefix = " ", star.suffix = "", star.char = "*", stars, 
-      dcolumn = TRUE, symbol = symbol, bold = 0, bold.prefix = "", 
-      bold.suffix = "", ci = ci, ci.test = ci.test)
+      posinfstring = "Inf", leading.zero, digits, 
+      se.prefix = " (", se.suffix = ")", star.prefix = " ", star.suffix = "", 
+      star.char = "*", stars, dcolumn = TRUE, symbol = symbol, bold = 0, 
+      bold.prefix = "", bold.suffix = "", ci = ci, ci.test = ci.test)
   
   # grouping
   output.matrix <- grouping(output.matrix, groups, indentation = "    ", 
@@ -313,14 +313,15 @@ texreg <- function(l, file = NULL, single.row = FALSE,
   # create output table with significance stars etc.
   ci <- logical()
   for (i in 1:length(models)) {
-    if (length(models[[i]]@se) == 0) {
+    if (length(models[[i]]@se) == 0 && length(models[[i]]@ci.up) > 0) {
       ci[i] <- TRUE
     } else {
       ci[i] <- FALSE
     }
   }
   output.matrix <- outputmatrix(m, single.row, 
-      neginfstring = "\\multicolumn{1}{c}{$-$Inf}", leading.zero, digits, 
+      neginfstring = "\\multicolumn{1}{c}{$-\\infty$}", 
+      posinfstring = "\\multicolumn{1}{c}{$\\infty$}", leading.zero, digits, 
       se.prefix = " \\; (", se.suffix = ")", star.prefix = "^{", 
       star.suffix = "}", star.char = "*", stars, dcolumn = dcolumn, 
       symbol, bold, bold.prefix = "\\mathbf{", bold.suffix = "}", ci = ci, 
@@ -760,17 +761,18 @@ htmlreg <- function(l, file = NULL, single.row = FALSE,
   # create output table with significance stars etc.
   ci <- logical()
   for (i in 1:length(models)) {
-    if (length(models[[i]]@se) == 0) {
+    if (length(models[[i]]@se) == 0 && length(models[[i]]@ci.up) > 0) {
       ci[i] <- TRUE
     } else {
       ci[i] <- FALSE
     }
   }
   output.matrix <- outputmatrix(m, single.row, neginfstring = "-Inf", 
-      leading.zero, digits, se.prefix = " (", se.suffix = ")", 
-      star.char = star.symbol, star.prefix = paste0("<sup", css.sup, ">"), 
-      star.suffix = "</sup>", stars, dcolumn = TRUE, symbol, bold = bold, 
-      bold.prefix = "<b>", bold.suffix = "</b>", ci = ci, ci.test = ci.test)
+      posinfstring = "Inf", leading.zero, digits, 
+      se.prefix = " (", se.suffix = ")", star.char = star.symbol, 
+      star.prefix = paste0("<sup", css.sup, ">"), star.suffix = "</sup>", 
+      stars, dcolumn = TRUE, symbol, bold = bold, bold.prefix = "<b>", 
+      bold.suffix = "</b>", ci = ci, ci.test = ci.test)
   
   # grouping
   output.matrix <- grouping(output.matrix, groups, 
